@@ -4,16 +4,14 @@ Main interface for iotdeviceadvisor service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_iotdeviceadvisor import (
         Client,
         IoTDeviceAdvisorClient,
     )
 
-    session = boto3.Session()
-
-    client: IoTDeviceAdvisorClient = boto3.client("iotdeviceadvisor")
-    session_client: IoTDeviceAdvisorClient = session.client("iotdeviceadvisor")
+    session = Session()
+    client: IoTDeviceAdvisorClient = session.client("iotdeviceadvisor")
     ```
 """
 from .client import IoTDeviceAdvisorClient
